TE923 - WeeWX 5.0
Author: Tom Keffer <tkeffer@gmail.com>

Skip to content

# TE923

Some station models will recognize up to 5 remote temperature/humidity sensor units. Use the hardware switch in each sensor unit to identify sensors. Use the `sensor_map` in `weewx.conf` to associate each sensor with a database field.

The station has either 208 or 3442 history records, depending on the model. With an archive interval set to 5 minutes, that is just over a day (208 records) or about 23 days (3442 records).

The TE923 driver will read history records from the station when WeeWX starts up, but it does not support hardware record generation.

## Configuring with `wee_device`

Note

Make sure you stop `weewxd` before running `wee_device`.

### `--help`

Invoking `wee_device` with the `--help` option

    wee_device /home/weewx/weewx.conf --help

will produce something like this:

    Using configuration file /home/weewx/weewx.conf
    Using TE923 driver version 0.21 (weewx.drivers.te923)
    Usage: wee_device [config_file] [options] [--debug] [--help]

    Configuration utility for weewx devices.

    Options:
    -h, --help            show this help message and exit
    --debug               display diagnostic information while running
    -y                    answer yes to every prompt
    --info                display weather station configuration
    --current             get the current weather conditions
    --history=N           display N history records
    --history-since=N     display history records since N minutes ago
    --minmax              display historical min/max data
    --get-date            display station date
    --set-date=YEAR,MONTH,DAY
    set station date
    --sync-date           set station date using system clock
    --get-location-local  display local location and timezone
    --set-location-local=CITY|USR,LONG_DEG,LONG_MIN,E|W,LAT_DEG,LAT_MIN,N|S,TZ,DST
    set local location and timezone
    --get-location-alt    display alternate location and timezone
    --set-location-alt=CITY|USR,LONG_DEG,LONG_MIN,E|W,LAT_DEG,LAT_MIN,N|S,TZ,DST
    set alternate location and timezone
    --get-altitude        display altitude
    --set-altitude=ALT    set altitude (meters)
    --get-alarms          display alarms
    --set-alarms=WEEKDAY,SINGLE,PRE_ALARM,SNOOZE,MAXTEMP,MINTEMP,RAIN,WIND,GUST
    set alarm state
    --get-interval        display archive interval
    --set-interval=INTERVAL
    set archive interval (minutes)
    --format=FORMAT       formats include: table, dict

    Be sure to stop weewx first before using. Mutating actions will request
    confirmation before proceeding.

### `--info`

Use `--info` to display the station configuration:

    wee_device --info

This will result in something like:

    Querying the station for the configuration...
    altitude: 16
    bat_1: True
    bat_2: True
    bat_3: True
    bat_4: True
    bat_5: True
    bat_rain: True
    bat_uv: False
    bat_wind: True
    latitude: 43.35
    longitude: -72.0
    version_bar: 23
    version_rcc: 16
    version_sys: 41
    version_uv: 20
    version_wind: 38

### `--current`

Use `--current` to display the current status of each sensor:

    wee_device --current

This will result in something like:

    Querying the station for current weather data...
    dateTime: 1454615168
    forecast: 5
    h_1: 41
    h_1_state: ok
    h_2: 48
    h_2_state: ok
    h_3: None
    h_3_state: no_link
    h_4: None
    h_4_state: no_link
    h_5: None
    h_5_state: no_link
    h_in: 44
    h_in_state: ok
    rain: 2723
    rain_state: ok
    slp: 1012.4375
    slp_state: ok
    storm: 0
    t_1: 13.9
    t_1_state: ok
    t_2: 21.5
    t_2_state: ok
    t_3: None
    t_3_state: no_link
    t_4: None
    t_4_state: no_link
    t_5: None
    t_5_state: no_link
    t_in: 22.85
    t_in_state: ok
    uv: None
    uv_state: no_link
    windchill: None
    windchill_state: invalid
    winddir: 12
    winddir_state: invalid
    windgust: None
    windgust_state: invalid
    windspeed: None
    windspeed_state: invalid

### `--set-interval`

TE923 stations ship from the factory with an archive interval of 1 hour (3600 seconds). To change the station's interval to 5 minutes (300 seconds), do the following:

    wee_device --set-interval=300

### `--history=N`

Use the `--history` action to display records from the logger in tabular or dictionary format.

For example, to display the most recent 30 records in dictionary format:

    wee_device --history=30 --format=dict

### `--clear-memory`

Use `--clear-memory` to erase all records from the logger memory.

## Station data

The following table shows which data are provided by the station hardware and which are calculated by WeeWX.

TE923 station data
Database Field | Observation | Loop | Archive
barometer | barometer | H | H
pressure |  | S | S
altimeter |  | S | S
inTemp | t_in | H | H
inHumidity | h_in | H | H
outTemp | t_1 | H | H
outHumidity | h_1 | H | H
outTempBatteryStatus | bat_1 | H |
outLinkStatus | link_1 | H |
windSpeed | windspeed | H | H
windDir | winddir | H | H
windGust | windgust | H | H
windBatteryStatus | bat_wind | H |
windLinkStatus | link_wind | H |
rain | rain | D | D
| rain_total | H | H
rainBatteryStatus | bat_rain | H |
rainLinkStatus | link_rain | H |
rainRate |  | S | S
dewpoint |  | S | S
windchill | windchill | H | H
heatindex |  | S | S
UV1 | uv | H | H
uvBatteryStatus | bat_uv | H |
uvLinkStatus | link_uv | H |
extraTemp1 | t_2 | H | H
extraHumid1 | h_2 | H | H
extraBatteryStatus1 | bat_2 | H |
extraLinkStatus1 | link_2 | H |
extraTemp2 | t_3 | H | H
extraHumid2 | h_3 | H | H
extraBatteryStatus2 | bat_3 | H |
extraLinkStatus2 | link_3 | H |
extraTemp3 | t_4 | H | H
extraHumid3 | h_4 | H | H
extraBatteryStatus3 | bat_4 | H |
extraLinkStatus3 | link_4 | H |
extraTemp4 | t_5 | H | H
extraHumid4 | h_5 | H | H
extraBatteryStatus4 | bat_5 | H |
extraLinkStatus4 | link_5 | H |

Some stations support up to 5 remote temperature/humidity sensors.

1 The UV data are available only with the optional solar radiation sensor.

H indicates data provided by Hardware
D indicates data calculated by the Driver
S indicates data calculated by the StdWXCalculate Service